#include "PIRadjust.h"
#include "time.h"
#include "touchbuttons.h"
#include "display.h"
#include "character.h"

#define DELAY_TIME_MODE_NORMAL    0
#define TIME_MODE_SETTING_DELAY   1
#define DELAY_TIME_INTERVAL 1000
// delay time setting modes
byte setDelayTimeMode = DELAY_TIME_MODE_NORMAL;

// set the delay time
int delayTime = 0;

// Define the coordinates to put on show the text "PIR" and the PIR delay value
#define X_COR 1   // X axis
#define Y_COR 9   // Y axis

void showPIR();

// manage delay time
void pirDelayTimeManager(unsigned long now, boolean modeChanged) {
  static unsigned long prev;
  if (setDelayTimeMode == DELAY_TIME_MODE_NORMAL) // Do not change mode when setting time
  {
    // Change global mode when top buttons pressed
    if (TL_KEY_DOWN)
    {
      goToPrevMode();
      return;
    }
    if (TR_KEY_DOWN)
    {
      goToNextMode();
      return;
    }

    // Enter setting time mode when pressing either buttons
    // Allow to set the time
    if ((BL_KEY_DOWN && BR_KEY_PRESSED || BR_KEY_DOWN && BL_KEY_PRESSED ) && displayMode == MODE_PIR_TIMER) {
      setDelayTimeMode = TIME_MODE_SETTING_DELAY;
      delayTime = wait;
      return;
    }
  }

  //setDelayTimeMode != DELAY_TIME_MODE_NORMAL (Setting time)
  else {
    // Exit setting time mode when pressing right bottom button
    if (BR_KEY_DOWN)
    {
      wait = delayTime;
      return;
    }
  }


  // Proceed only if just entered this mode or if interval has passed or if setting time
  if (!modeChanged && now - prev < DELAY_TIME_INTERVAL && setDelayTimeMode == DELAY_TIME_MODE_NORMAL)
    return;
  //prev = now;

  if (setDelayTimeMode == DELAY_TIME_MODE_NORMAL)
  {
    showPIR();
  }

  else //setDelayTimeMode != DELAY_TIME_MODE_NORMAL (Setting time)
  {
    showDelayTime(delayTime);
    if (BL_KEY_DOWN) // Bottom left button pressed, Save the delay time value in wait variable
    {
      if (setDelayTimeMode == TIME_MODE_SETTING_DELAY) // Finish setting hour, switch to setting minute
      {
        if(delayTime == 1){
        delayTime++;
        }
        wait = delayTime;
        setDelayTimeMode = DELAY_TIME_MODE_NORMAL;
      }
    }
    else if (TL_KEY_DOWN) // Top left button pressed, decrement minute
    {
      // Decrement minute
      if (setDelayTimeMode == TIME_MODE_SETTING_DELAY)
      {
        delayTime--;
        if (delayTime <= 0) {
          delayTime = 59;
        }
      }
    }
    else if (TR_KEY_DOWN)  // Top right button pressed, increment minute
    {
      // Increment minute
      if (setDelayTimeMode == TIME_MODE_SETTING_DELAY)
      {
        delayTime++;
        if (delayTime > 59) {
          delayTime = 1;
        }
      }
    }
  }
}

// count minutes
void showDelayTime(int num) {
  clearFrame();
  // set PIR
   addCharToFrame(1, 0, 13); // Example: Display 'P' at position (1,  0)
  addCharToFrame(6, 0, 14); // Example: Display 'I' at position (6, 0)
  addCharToFrame(10, 0, 15); // Example: Display 'R' at position (10, 0)

  int first_num = num / 10;
  int second_num = num % 10;
  addCharToFrame(X_COR + 1, 8, first_num);
  addCharToFrame(X_COR + 9, 8, second_num);
  updateDisplay();
}

void showPIR() {
  clearFrame();
  addCharToFrame(1, 0, 13); // Example: Display 'P' at position (1,  0)
  addCharToFrame(6, 0, 14); // Example: Display 'I' at position (6, 0)
  addCharToFrame(10, 0, 15); // Example: Display 'R' at position (10, 0)
  updateDisplay();
}